API Changes
===========

0.4.0 API changes
-----------------

Planification
~~~~~~~~~~~~~

 - `~hxntools.anc350.Anc350Controller.setup_dc` is now a plan
 - `~hxntools.anc350._dc_toggle` is now a plan
 - `~hxntools.anc350.dc_toggle` is now a plan
 - `~hxntools.anc350.dc_on` is now a plan
 - `~hxntools.anc350.dc_off` is now a plan
